baseObjects.Normalizer

|  | ## Cheshire3 Object Model: Class Normalizer

Module baseObjects :: Class Normalizer

## Class Normalizer
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                           Normalizer

Known Subclasses:
  normalizer.SimpleNormalizer

Normalizer objects are chained after Extractors in order to transform the data from the record or query. A Normalizer might standardise case, perform stemming or transform a date into ISO8601 format. Normalizers are also needed to transform the terms in a request into the same format as the term in the Index. For example a date index might be searched using a free text date and that would need to be parsed into the normalised form in order to compare it with the stored data.
Instance Methods

process_hash(self, session, data) Process a hash of values into alternative forms.
process_string(self, session, data) Process a string into an alternative form.
Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### process_hash(self, session, data) | source code
Process a hash of values into alternative forms.

### process_string(self, session, data) | source code
Process a string into an alternative form.